==> dotup_flutter_simulator-3.1.2.tar.gz: lib/src/simulator/simulator_app.dart <==
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../device/device_descriptor.dart';
import 'simulator_controller.dart';
import '../settings/simulator_settings.dart';
import 'simulator_container.dart';

class SimulatorApp extends StatefulWidget {
  const SimulatorApp({
    Key? key,
    required this.appBuilder,
    required this.device,
    this.orientation = Orientation.portrait,
    required this.settings,
    SimulatorController? controller,
    this.disableSimulatorFrame = false,
  })  : _controller = controller,
        super(key: key);

  final WidgetBuilder appBuilder;
  final DeviceDescriptor device; // TODO: remove
  final Orientation? orientation;
  final SimulatorController? _controller;
  final SimulatorSettings settings;
  final bool disableSimulatorFrame;

  @override
  State<SimulatorApp> createState() => _SimulatorAppState();
}

class _SimulatorAppState extends State<SimulatorApp> {
  SimulatorController? controller;

  @override
  Widget build(BuildContext context) {
    if (widget.disableSimulatorFrame) {
      return widget.appBuilder(context);
    }

    controller ??= (widget._controller ?? SimulatorController(widget.settings));
    // final size = Size(400, 800);

    return Directionality(
      key: ValueKey(widget.device),
      textDirection: TextDirection.ltr,
      child: ChangeNotifierProvider<SimulatorController>(
        create: (context) => controller!,
        child: _SimulatorApp(
          appBuilder: widget.appBuilder,
          // device: widget.device,
          controller: controller!,
        ),
        // child: WidgetsApp(
        //   // onGenerateRoute: generate,
        //   debugShowCheckedModeBanner: false,
        //   pageRouteBuilder: <T>(RouteSettings settings, WidgetBuilder builder) {
        //     return MaterialPageRoute(builder: builder, settings: settings);
        //   },
        //   home: DisplayContainer(
        //     device: device,
        //     child: (_) => MediaQuery(data: _getMediaQueryData(device), child: appBuilder(context)),
        //   ),
        //   color: Colors.red,
        // ),
      ),
    );
  }
}

class _SimulatorApp extends StatelessWidget {
  const _SimulatorApp({
    Key? key,
    required this.appBuilder,
    // required this.device,
    required this.controller,
  }) : super(key: key);

  final WidgetBuilder appBuilder;
  // final DeviceDescriptor device;
  final SimulatorController controller;

  @override
  Widget build(BuildContext context) {
    final b = context.select<SimulatorController, Brightness>((x) => x.brightness);

    return MaterialApp(
      useInheritedMediaQuery: true,
      theme: ThemeData.light(),
      darkTheme: ThemeData.dark(),
      // return WidgetsApp(
      // onGenerateRoute: generate,
      debugShowCheckedModeBanner: false,
      themeMode: b == Brightness.dark ? ThemeMode.dark : ThemeMode.light,
      // pageRouteBuilder: <T>(RouteSettings settings, WidgetBuilder builder) {
      //   return MaterialPageRoute(builder: builder, settings: settings);
      // },
      // theme: ThemeData.light(),
      routes: {
        '/': (context) {
          controller.setRealMediaQuery(MediaQuery.of(context));
          return SimulatorContainer(
            builder: (_) => MediaQuery(
              data: _getMediaQueryData(),
              child: appBuilder(context),
            ),
          );
        }
      },
      // home: DisplayContainer(
      //   device: device,
      //   child: (_) => MediaQuery(data: _getMediaQueryData(device), child: appBuilder(context)),
      // ),
      color: Colors.green,
    );
  }

  MediaQueryData _getMediaQueryData() {
    return MediaQueryData(size: controller.currentDevice.size).copyWith(
      platformBrightness: controller.brightness,
      // padding: controller.currentDevice.padding,
    );
  }
}

==> dotup_flutter_simulator-3.1.3.tar.gz: lib/src/simulator/simulator_app.dart <==
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../device/device_descriptor.dart';
import 'simulator_controller.dart';
import '../settings/simulator_settings.dart';
import 'simulator_container.dart';

class SimulatorApp extends StatefulWidget {
  const SimulatorApp({
    Key? key,
    required this.appBuilder,
    required this.device,
    this.orientation = Orientation.portrait,
    required this.settings,
    SimulatorController? controller,
    this.disableSimulatorFrame = false,
  })  : _controller = controller,
        super(key: key);

  final WidgetBuilder appBuilder;
  final DeviceDescriptor device; // TODO: remove
  final Orientation? orientation;
  final SimulatorController? _controller;
  final SimulatorSettings settings;
  final bool disableSimulatorFrame;

  @override
  State<SimulatorApp> createState() => _SimulatorAppState();
}

class _SimulatorAppState extends State<SimulatorApp> {
  SimulatorController? controller;

  @override
  Widget build(BuildContext context) {
    if (widget.disableSimulatorFrame) {
      return widget.appBuilder(context);
    }

    controller ??= (widget._controller ?? SimulatorController(widget.settings));
    // final size = Size(400, 800);

    return Directionality(
      key: ValueKey(widget.device),
      textDirection: TextDirection.ltr,
      child: ChangeNotifierProvider<SimulatorController>(
        create: (context) => controller!,
        child: _SimulatorApp(
          appBuilder: widget.appBuilder,
          // device: widget.device,
          controller: controller!,
        ),
        // child: WidgetsApp(
        //   // onGenerateRoute: generate,
        //   debugShowCheckedModeBanner: false,
        //   pageRouteBuilder: <T>(RouteSettings settings, WidgetBuilder builder) {
        //     return MaterialPageRoute(builder: builder, settings: settings);
        //   },
        //   home: DisplayContainer(
        //     device: device,
        //     child: (_) => MediaQuery(data: _getMediaQueryData(device), child: appBuilder(context)),
        //   ),
        //   color: Colors.red,
        // ),
      ),
    );
  }
}

class _SimulatorApp extends StatelessWidget {
  const _SimulatorApp({
    Key? key,
    required this.appBuilder,
    // required this.device,
    required this.controller,
  }) : super(key: key);

  final WidgetBuilder appBuilder;
  // final DeviceDescriptor device;
  final SimulatorController controller;

  @override
  Widget build(BuildContext context) {
    final b = context.select<SimulatorController, Brightness>((x) => x.brightness);

    return MaterialApp(
      useInheritedMediaQuery: true,
      theme: ThemeData.light(),
      darkTheme: ThemeData.dark(),
      // return WidgetsApp(
      // onGenerateRoute: generate,
      debugShowCheckedModeBanner: false,
      themeMode: b == Brightness.dark ? ThemeMode.dark : ThemeMode.light,
      // pageRouteBuilder: <T>(RouteSettings settings, WidgetBuilder builder) {
      //   return MaterialPageRoute(builder: builder, settings: settings);
      // },
      // theme: ThemeData.light(),
      routes: {
        '/': (context) {
          controller.setRealMediaQuery(MediaQuery.of(context));
          final simulator = SimulatorContainer(
            builder: (_) => MediaQuery(
              data: _getMediaQueryData(),
              child: appBuilder(context),
            ),
          );

          return controller.settings.useSafeArea ? SafeArea(child: simulator) : simulator;
        }
      },
      // home: DisplayContainer(
      //   device: device,
      //   child: (_) => MediaQuery(data: _getMediaQueryData(device), child: appBuilder(context)),
      // ),
      color: Colors.green,
    );
  }

  MediaQueryData _getMediaQueryData() {
    return MediaQueryData(size: controller.currentDevice.size).copyWith(
      platformBrightness: controller.brightness,
      // padding: controller.currentDevice.padding,
    );
  }
}
